CsvConnector
=====================================


.. autoclass:: sdgx.data_connectors.csv_connector.CsvConnector
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    :private-members:
